Description Usage Arguments Value
is.color
1 | is.color(x)
|
x |
a vector of values |
a logical vector of the same length as x indicating whether each element of x is a valid color
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.